{{ fullname }}
{{ underline }}

.. currentmodule:: {{ module }}

.. auto{{ objtype }}:: {{ objname }}


.. include:: {{module}}.{{objname}}.examples


.. raw:: html

	       <div style='clear:both'></div>
